@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class QrtoolkitModelsConfig(AppConfig):
-    name = 'qrtoolkit_models'
+    name = 'qrtoolkit_core'
